@@ -75,8 +75,13 @@ CDesktop::CDesktop()
     XChangeProperty(QX11Info::display(), winId(), appletSettingAtom, XA_CARDINAL, 32,
 		    PropModeReplace, (unsigned char*)&settings, 1);
 
-    if (QFile( QDir::homePath()+"/MyDocs/rds.svg").exists())
-        renderer = new QSvgRenderer(QDir::homePath()+"/MyDocs/rds.svg", this);
+    QSettings cfg;
+    if (!cfg.value("main/theme","").toString().isEmpty()) {
+        if (QFile::exists(QDir::homePath() + QLatin1String("/.fmrdsnotify/")+cfg.value("main/theme","").toString()+QLatin1String(".svg")))
+            renderer = new QSvgRenderer(QDir::homePath() + QLatin1String("/.fmrdsnotify/")+cfg.value("main/theme","").toString()+QLatin1String(".svg"), this);
+        else
+            renderer = new QSvgRenderer(QLatin1String(":icons/rds.svg"), this);
+    }
     else
         renderer = new QSvgRenderer(QLatin1String(":icons/rds.svg"), this);
 
@@ -162,6 +167,7 @@ bool QWidget::x11Event ( XEvent * event )
 
   if (event->xclient.message_type == appletShowSettingAtom ) { 
       CDlgSetup *mySetup = new CDlgSetup();
+      connect(mySetup, SIGNAL(newTheme(QString)), this, SLOT(slotDrawTheme(QString)));
       mySetup->exec();
       dirty = true;
       update();
@@ -310,3 +316,11 @@ void CDesktop::slotClickedPrevious(bool checked){
     update();
     qDebug() << "Current frequency=" << CFMRadio::self().getFrequency();
 }
+
+void CDesktop::slotDrawTheme(QString theme)
+{
+    renderer->load(QDir::homePath() + QLatin1String("/.fmrdsnotify/")+theme+QLatin1String(".svg"));
+    resize( renderer->defaultSize());
+    dirty = true;
+    update();
+}
